@@ -1,7 +1,7 @@
 /*
  * MP3/MPlayer plugin to VDR (C++)
  *
- * (C) 2001-2005 Stefan Huelswitt <s.huelswitt@gmx.de>
+ * (C) 2001-2009 Stefan Huelswitt <s.huelswitt@gmx.de>
  *
  * This code is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -58,6 +58,7 @@
 
 #define CDDB_PROTO 5                   // used protocol level
 #define CDDB_TOUT  30*1000             // connection timeout (ms)
+#define CDDB_CHARSET "ISO8859-1"       // data charset
 
 const char *cddbpath="/var/lib/cddb";  // default local cddb path
 
@@ -410,7 +411,7 @@ private:
   //
   cCDDBSong *GetTrack(const char *name, unsigned int pos);
   cCDDBSong *FindTrack(int tr);
-  void Strcat(char * &store, char *value);
+  void Strcat(char * &store, const char *value);
   bool Split(const char *source, char div, char * &first, char * &second, bool only3=false);
   void Put(const char *from, char * &to);
   void Clean(void);
@@ -472,6 +473,7 @@ bool cCDDBDisc::Load(cDiscID *id, const char *filename)
   DiscID=id->discid;
   FILE *f=fopen(filename,"r");
   if(f) {
+    cCharSetConv csc(CDDB_CHARSET);
     char buff[1024];
     while(fgets(buff,sizeof(buff),f)) {
       int i=strlen(buff);
@@ -484,7 +486,7 @@ bool cCDDBDisc::Load(cDiscID *id, const char *filename)
         if(p) {
            *p=0;
            char *name =compactspace(buff);
-           char *value=compactspace(p+1);
+           const char *value=csc.Convert(compactspace(p+1));
            if(*name && *value) {
              if(!strcasecmp(name,"DTITLE")) Strcat(DTitle,value);
              else if(!strcasecmp(name,"EXTD")) Strcat(ExtD,value);
@@ -577,7 +579,8 @@ bool cCDDBDisc::Load(cDiscID *id, const char *filename)
 bool cCDDBDisc::Split(const char *source, char div, char * &first, char * &second, bool only3)
 {
   int pos=-1, n=0;
-  char *p, l[4]={ ' ',div,' ',0 };
+  const char *p;
+  char l[4]={ ' ',div,' ',0 };
   if ((p=strstr(source,l))) { pos=p-source; n=3; }
   else if(!only3 && (p=strchr(source,div)))  { pos=p-source; n=1; }
   if(pos>=0) {
@@ -588,7 +591,7 @@ bool cCDDBDisc::Split(const char *source, char div, char * &first, char * &secon
   return false;
 }
 
-void cCDDBDisc::Strcat(char * &store, char *value)
+void cCDDBDisc::Strcat(char * &store, const char *value)
 {
   if(store) {
     char *n=MALLOC(char,strlen(store)+strlen(value)+1);
@@ -643,7 +646,7 @@ private:
   bool RemoteGet(cDiscID *id);
   bool GetLine(char *buff, int size, bool log=true);
   int GetCddbResponse(void);
-  int DoCddbCmd(char *format, ...);
+  int DoCddbCmd(const char *format, ...);
 public:
   cCDDB(void);
   virtual ~cCDDB();
@@ -706,9 +709,9 @@ bool cCDDB::RemoteGet(cDiscID *id)
   if(net->Connect(MP3Setup.CddbHost,MP3Setup.CddbPort)) {
     int code=GetCddbResponse();
     if(code/100==2) {
-      char *host=getenv("HOSTNAME"); if(!host) host="unknown";
-      char *user=getenv("USER"); if(!user) user="nobody";
-      code=DoCddbCmd("cddb hello %s %s %s %s\n",user,host,PLUGIN_NAME,PLUGIN_VERSION);
+      const char *host=getenv("HOSTNAME"); if(!host) host="unknown";
+      const char *user=getenv("USER"); if(!user) user="nobody";
+      code=DoCddbCmd("cddb hello %s %s %s %s\n",user,host,PLUGIN_NAME,PluginVersion);
       if(code/100==2) {
         code=DoCddbCmd("proto %d\n",CDDB_PROTO);
         if(code>0) {
@@ -730,8 +733,7 @@ bool cCDDB::RemoteGet(cDiscID *id)
               char *s=index(cat,' '); if(s) *s=0;
               code=DoCddbCmd("cddb read %s %08x\n",cat,id->discid);
               if(code==210) {
-                char *name=0;
-                asprintf(&name,"%s/%s/%08x",cddbpath,cat,id->discid);
+                char *name=aprintf("%s/%s/%08x",cddbpath,cat,id->discid);
                 if(MakeDirs(name,false)) {
                   FILE *out=fopen(name,"w");
                   if(out) {
@@ -783,12 +785,12 @@ int cCDDB::GetCddbResponse(void)
   return -1;
 }
 
-int cCDDB::DoCddbCmd(char *format, ...)
+int cCDDB::DoCddbCmd(const char *format, ...)
 {
   va_list ap;
   va_start(ap,format);
   char *buff=0;
-  vasprintf(&buff,format,ap);
+  if(vasprintf(&buff,format,ap)<0);
   va_end(ap);
 #ifdef CDDB_DEBUG
   printf("cddb: -> %s",buff);
@@ -828,6 +830,7 @@ bool cSndInfo::DoScan(bool KeepOpen)
   cCacheData *dat=InfoCache.Search(file);
   if(dat) {
     Set(dat); dat->Unlock();
+    ConvertToSys();
     if(!DecoderID) {
       DecoderID=DEC_SND;
       InfoCache.Cache(this,file);
@@ -845,19 +848,20 @@ bool cSndInfo::DoScan(bool KeepOpen)
   Channels=file->sfi.channels;
   ChMode=Channels>1 ? 3:0;
   Total=Frames/SampleFreq;
-  Bitrate=file->Filesize*8/Total; //XXX SampleFreq*Channels*file->sfi.pcmbitwidth;
+  Bitrate=Total ? file->Filesize*8/Total : 0; //XXX SampleFreq*Channels*file->sfi.pcmbitwidth;
   DecoderID=DEC_SND;
 
   InfoDone();
   InfoCache.Cache(this,file);
-  return Abort(true);  
+  ConvertToSys();
+  return Abort(true);
 }
 
 bool cSndInfo::CDDBLookup(const char *filename)
 {
   if(id->Get()) {
     int tr;
-    char *s=strstr(filename,CDFS_TRACK);
+    const char *s=strstr(filename,CDFS_TRACK);
     if(s && sscanf(s+strlen(CDFS_TRACK),"%d",&tr)==1) {
       d(printf("snd: looking up disc id %08x track %d\n",id->discid,tr))
       return cddb.Lookup(id,tr-1,this);
