@@ -1,7 +1,7 @@
 /*
  * MP3/MPlayer plugin to VDR (C++)
  *
- * (C) 2001-2007 Stefan Huelswitt <s.huelswitt@gmx.de>
+ * (C) 2001-2009 Stefan Huelswitt <s.huelswitt@gmx.de>
  *
  * This code is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -36,6 +36,7 @@
 #include "decoder-mp3-stream.h"
 #include "decoder-snd.h"
 #include "decoder-ogg.h"
+#include "decoder-ogg-stream.h"
 
 #define CACHEFILENAME     "id3info.cache"
 #define CACHESAVETIMEOUT  120 // secs
@@ -53,6 +54,35 @@ int MakeHashBuff(const char *buff, int len)
   return h;
 }
 
+// --- cStrConv ----------------------------------------------------------------
+
+class cStrConv : private cMutex {
+private:
+  cCharSetConv toSys;
+public:
+  cStrConv(void):toSys("UTF-8",cCharSetConv::SystemCharacterTable()) {}
+  char *ToSys(char *from);
+  };
+
+static cStrConv *strconv;
+  
+char *cStrConv::ToSys(char *from)
+{
+  if(from) {
+    Lock();
+    const char *r=toSys.Convert(from);
+    Unlock();
+    if(r!=from) {
+      char *n=strdup(r);
+      if(n) {
+        free(from);
+        return n;
+        }
+      }
+    }
+  return from;
+}
+
 // --- cSongInfo ---------------------------------------------------------------
 
 cSongInfo::cSongInfo(void)
@@ -75,12 +105,18 @@ void cSongInfo::Clear(void)
   free(Album); Album=0;
   Year=-1;
   Level=Peak=0.0;
-  infoDone=false;
+  infoDone=false; utf8clean=true;
 }
 
-void cSongInfo::Set(cSongInfo *si)
+void cSongInfo::Set(cSongInfo *si, bool update)
 {
-  Clear(); InfoDone();
+  if(!update || si->Utf8Clean()) {
+    Clear();
+    Title=si->Title ? strdup(si->Title):0;
+    Artist=si->Artist ? strdup(si->Artist):0;
+    Album=si->Album ? strdup(si->Album):0;
+    utf8clean=si->utf8clean;
+    }
   Frames=si->Frames;
   Total=si->Total;
   SampleFreq=si->SampleFreq;
@@ -89,21 +125,19 @@ void cSongInfo::Set(cSongInfo *si)
   MaxBitrate=si->MaxBitrate;
   ChMode=si->ChMode;
   Year=si->Year;
-  Title=si->Title ? strdup(si->Title):0;
-  Artist=si->Artist ? strdup(si->Artist):0;
-  Album=si->Album ? strdup(si->Album):0;
   if(si->Level>0.0) { // preserve old level
     Level=si->Level;
     Peak=si->Peak;
     }
   DecoderID=si->DecoderID;
+  InfoDone();
 }
 
 void cSongInfo::FakeTitle(const char *filename, const char *extention)
 {
   // if no title, try to build a reasonable from the filename
   if(!Title && filename)  {
-    char *s=rindex(filename,'/');
+    const char *s=rindex(filename,'/');
     if(s && *s=='/') {
       s++;
       Title=strdup(s);
@@ -113,14 +147,24 @@ void cSongInfo::FakeTitle(const char *filename, const char *extention)
         if(l>0 && !strcasecmp(Title+l,extention)) Title[l]=0;
         }
       else {                                     // strip any extention
-        s=rindex(Title,'.');
-        if(s && *s=='.' && strlen(s)<=5) *s=0;
+        char *e=rindex(Title,'.');
+        if(e && *e=='.' && strlen(e)<=5) *e=0;
         }
       d(printf("mp3: faking title '%s' from filename '%s'\n",Title,filename))
       }
     }
 }
 
+void cSongInfo::ConvertToSys(void)
+{
+  if(cCharSetConv::SystemCharacterTable()) {
+    Title=strconv->ToSys(Title);
+    Artist=strconv->ToSys(Artist);
+    Album=strconv->ToSys(Album);
+    utf8clean=false;
+    }
+}
+
 // --- cFileInfo ---------------------------------------------------------------
 
 cFileInfo::cFileInfo(void)
@@ -177,7 +221,7 @@ bool cFileInfo::FileInfo(bool log)
         FsType=0;
         struct statfs64 sfs;
         if(!statfs64(Filename,&sfs)) {
-          if(Removable()) asprintf(&FsID,"%llx:%llx",sfs.f_blocks,sfs.f_files);
+          if(Removable()) FsID=aprintf("%llx:%llx",sfs.f_blocks,sfs.f_files);
           FsType=sfs.f_type;
           }
         else if(errno!=ENOSYS && log) { esyslog("ERROR: can't statfs %s: %s",Filename,strerror(errno)); }
@@ -215,6 +259,7 @@ cDecoder *cDecoders::FindDecoder(cFileObj *Obj)
 #endif
 #ifdef HAVE_VORBISFILE
         case DEC_OGG:  decoder=new cOggDecoder(full); break;
+        case DEC_OGGS: decoder=new cOggStreamDecoder(full); break;
 #endif
         default:       esyslog("ERROR: bad DecoderID '%s' from info cache: %s",cDecoders::ID2Str(dat->DecoderID),full); break;
         }
@@ -238,6 +283,10 @@ cDecoder *cDecoders::FindDecoder(cFileObj *Obj)
       decoder=new cOggDecoder(full);
       if(!decoder || !decoder->Valid()) { delete decoder; decoder=0; }
       }
+    if(!decoder) {
+      decoder=new cOggStreamDecoder(full);
+      if(!decoder || !decoder->Valid()) { delete decoder; decoder=0; }
+      }
 #endif
     if(!decoder) {
       decoder=new cMP3StreamDecoder(full);
@@ -259,6 +308,7 @@ const char *cDecoders::ID2Str(int id)
     case DEC_MP3S: return DEC_MP3S_STR;
     case DEC_SND:  return DEC_SND_STR;
     case DEC_OGG:  return DEC_OGG_STR;
+    case DEC_OGGS: return DEC_OGGS_STR;
     }
   return 0;
 }
@@ -269,6 +319,7 @@ int cDecoders::Str2ID(const char *str)
   else if(!strcmp(str,DEC_MP3S_STR)) return DEC_MP3S;
   else if(!strcmp(str,DEC_SND_STR )) return DEC_SND;
   else if(!strcmp(str,DEC_OGG_STR )) return DEC_OGG;
+  else if(!strcmp(str,DEC_OGGS_STR)) return DEC_OGGS;
   return 0;
 }
 
@@ -349,8 +400,18 @@ bool cCacheData::Purge(void)
   return false;
 }
 
+bool cCacheData::Check8bit(const char *str)
+{
+  if(str) while(*str) if(*str++ & 0x80) return true;
+  return false;
+}
+
 bool cCacheData::Upgrade(void)
 {
+  if(version<8) {
+    if(Check8bit(Title) || Check8bit(Artist) || Check8bit(Album))
+      return false;              // Trash entries not 7bit clean
+    }
   if(version<7) {
     if(DecoderID==DEC_SND || (Title && startswith(Title,"track-")))
       return false;              // Trash older SND entries (incomplete)
@@ -372,10 +433,10 @@ bool cCacheData::Upgrade(void)
   return true;
 }
 
-void cCacheData::Create(cFileInfo *fi, cSongInfo *si)
+void cCacheData::Create(cFileInfo *fi, cSongInfo *si, bool update)
 {
   cFileInfo::Set(fi);
-  cSongInfo::Set(si);
+  cSongInfo::Set(si,update);
   hash=MakeHash(Filename);
   Touch();
 }
@@ -410,7 +471,8 @@ bool cCacheData::Save(FILE *f)
 
 bool cCacheData::Load(FILE *f)
 {
-  char buf[1024], *delimiters="=\n";
+  static const char delimiters[] = { "=\n" };
+  char buf[1024];
 
   cFileInfo::Clear();
   cSongInfo::Clear();
@@ -471,14 +533,14 @@ void cInfoCache::Cache(cSongInfo *info, cFileInfo *file)
   lock.Lock();
   cCacheData *dat=Search(file);
   if(dat) {
-    dat->Create(file,info);
+    dat->Create(file,info,true);
     Modified();
     dat->Unlock();
     d(printf("cache: updating infos for %s\n",file->Filename))
     }
   else {
     dat=new cCacheData;
-    dat->Create(file,info);
+    dat->Create(file,info,false);
     AddEntry(dat);
     d(printf("cache: caching infos for %s\n",file->Filename))
     }
@@ -548,7 +610,7 @@ bool cInfoCache::Purge(void)
 void cInfoCache::Action(void)
 {
   d(printf("cache: id3 cache purge thread started (pid=%d)\n",getpid()))
-  nice(3);
+  if(nice(3)<0);
   lock.Lock();
   for(int i=0,n=0 ; i<CACHELINES && Running(); i++) {
     cCacheData *dat=FirstEntry(i);
@@ -600,6 +662,8 @@ void cInfoCache::Save(bool force)
 
 void cInfoCache::Load(void)
 {
+  if(!strconv) strconv=new cStrConv;
+
   char *name=CacheFile();
   if(access(name,F_OK)==0) {
     isyslog("loading id3 cache from %s",name);
