@@ -1,7 +1,7 @@
 /*
  * MP3/MPlayer plugin to VDR (C++)
  *
- * (C) 2001-2007 Stefan Huelswitt <s.huelswitt@gmx.de>
+ * (C) 2001-2009 Stefan Huelswitt <s.huelswitt@gmx.de>
  *
  * This code is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -80,14 +80,9 @@ void cMPlayerStatus::SetVolume(int Volume, bool Absolute)
   Lock();
   if(Absolute && Volume==0) mute=true;
   else {
-#if APIVERSNUM>=10401
-#if APIVERSNUM==10401
-#warning Caution! This code does not work with VDR 1.4.1 and 1.4.1-1. You can ignore this warning if you are using VDR 1.4.1-2 or later.
-#endif
     if(!Absolute)
       volume+=Volume;
     else
-#endif
       volume=Volume;
     if(volume>0) mute=false;
     }
@@ -186,8 +181,7 @@ bool cMPlayerResume::OpenResume(const cFileObj *file)
     modified=global=false;
     free(resfile); resfile=0;
     delete resobj; resobj=new cFileObj(file);
-    char *s;
-    asprintf(&s,file->Subdir() ? "%s/%s":"%s",file->Source()->BaseDir(),file->Subdir());
+    char *s=aprintf(file->Subdir() ? "%s/%s":"%s",file->Source()->BaseDir(),file->Subdir());
     if(MPlayerSetup.ResumeMode==1 || 
        (access(s,W_OK) && (errno==EACCES || errno==EROFS))) {
       global=true;
@@ -328,15 +322,15 @@ void cMPlayerPlayer::Activate(bool On)
       if(slave) {
         Play(); // MPlayer ignores "quit" while paused
         MPlayerControl("quit");
-        int until=time_ms()+3000; // wait some time until MPlayer is gone
+        cTimeMs until(3000); // wait some time until MPlayer is gone
         d(printf("mplayer: waiting for child exit"))
         while(Active()) {
-          if(time_ms()>until) {
+          if(until.TimedOut()) {
             kill(pid,SIGKILL); // kill it anyways
             d(printf(" SIGKILL"))
             break;
             }
-          SLEEP(250);
+          cCondWait::SleepMs(250);
           d(printf(".")) d(fflush(stdout))
           }
         d(printf("\n"))
@@ -403,6 +397,10 @@ bool cMPlayerPlayer::Fork(void)
     else aid[0]=0;
     snprintf(cmd,sizeof(cmd),"%s \"%s\" %s%s",MPlayerCmd,fname,MPlayerSetup.SlaveMode?"SLAVE":"",aid);
     free(fname);
+    // give index of primary dvb adapter device to mplayer via environment variable
+    char dvb[4];
+    snprintf(dvb,sizeof(dvb),"%d",cDevice::PrimaryDevice()->CardIndex()+1);
+    setenv("DVB_DEVICE",dvb,1);
     execle("/bin/sh","sh","-c",cmd,(char *)0,environ);
     esyslog("ERROR: exec failed for %s: (%d) %s",cmd,errno,strerror(errno));
     exit(127);
@@ -586,7 +584,7 @@ void cMPlayerPlayer::MPlayerControl(const char *format, ...)
     va_list ap;
     va_start(ap,format);
     char *buff=0;
-    vasprintf(&buff,format,ap);
+    if(vasprintf(&buff,format,ap)<0);
     Lock();
     // check for writeable pipe i.e. prevent broken pipe signal
     if(!brokenPipe) {
