@@ -1,7 +1,7 @@
 /*
  * MP3/MPlayer plugin to VDR (C++)
  *
- * (C) 2001-2005 Stefan Huelswitt <s.huelswitt@gmx.de>
+ * (C) 2001-2009 Stefan Huelswitt <s.huelswitt@gmx.de>
  *
  * This code is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,11 +26,14 @@ extern const char *MPlayerCmd;
 
 // ----------------------------------------------------------------
 
+#define MAX_KEYCMD 32
+
 class cMPlayerSetup {
 public:
   int SlaveMode;
   int ResumeMode;
   int HideMainMenu;
+  char KeyCmd[10][MAX_KEYCMD];
 public:
   cMPlayerSetup(void);
   };
